==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/Q2ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q2ExpressionDescription } from "./Q2ExpressionDescription";
/**
 * @hidden
 */
export let Q2ExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class Q2ExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (Q2ExpressionDescriptionMetadata.a == null) {
                Q2ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Q2ExpressionDescriptionMetadata.c(Q2ExpressionDescriptionMetadata.a);
            }
            if (a.k(Q2ExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(Q2ExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            Q2ExpressionDescriptionMetadata.b(a);
            a.ad("Q2Expression", () => new Q2ExpressionDescription());
            a.ac("Q2Expression", Q2ExpressionDescriptionMetadata.a);
        }
    }
    Q2ExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(Q2ExpressionDescriptionMetadata, 'Q2ExpressionDescriptionMetadata');
    Q2ExpressionDescriptionMetadata.a = null;
    return Q2ExpressionDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/Q2ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q2ExpressionDescription } from "./Q2ExpressionDescription";
/**
 * @hidden
 */
export let Q2ExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class Q2ExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (Q2ExpressionDescriptionMetadata.a == null) {
                Q2ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Q2ExpressionDescriptionMetadata.c(Q2ExpressionDescriptionMetadata.a);
            }
            if (a.k(Q2ExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(Q2ExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            Q2ExpressionDescriptionMetadata.b(a);
            a.ae("Q2Expression", () => new Q2ExpressionDescription());
            a.ad("Q2Expression", Q2ExpressionDescriptionMetadata.a);
        }
    }
    Q2ExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(Q2ExpressionDescriptionMetadata, 'Q2ExpressionDescriptionMetadata');
    Q2ExpressionDescriptionMetadata.a = null;
    return Q2ExpressionDescriptionMetadata;
})();
